@@ -104,7 +104,7 @@ test_that("flat prior factor", {
                                factor_priorfacloadtype = "normal",
                                factor_priorfacload = 1e6,
                                factor_heteroskedastic = c(FALSE, FALSE),
-                               factor_priorhomoskedastic = matrix(c(0.01,.01), ncol(data), 2))
+                               factor_priorhomoskedastic = matrix(c(1e-6,1e-6), ncol(data), 2))
  set.seed(123)
   mod <- bvar(data, lags = 2, prior_intercept = 1e6, prior_phi = phi,
               prior_sigma = sigma, draws = 10000)
@@ -122,7 +122,7 @@ test_that("flat prior cholesky", {
                                cholesky_U_prior = "normal",
                                cholesky_normal_sds = 1e6,
                                cholesky_heteroscedastic = FALSE,
-                               cholesky_priorhomoscedastic = matrix(c(0.01,0.01), ncol(data), 2))
+                               cholesky_priorhomoscedastic = matrix(c(1e-6,1e-6), ncol(data), 2))
   set.seed(123)
   mod <- bvar(data, lags = 2, prior_intercept = 1e6, prior_phi = phi,
               prior_sigma = sigma, draws = 10000)
@@ -131,3 +131,19 @@ test_that("flat prior cholesky", {
 
   expect_lt(max(abs(ols-phi_post_mean)),0.01)
 })
+
+test_that("homoscedastic factor VAR input", {
+  data <- usmacro_growth[,c("GDPC1","CPIAUCSL","FEDFUNDS")]
+  phi <- specify_prior_phi(data = data, lags = 2L, prior = "normal",
+                           normal_sds = 1e6)
+  sigma <- specify_prior_sigma(data = data, type = "factor",
+                               factor_factors = 2,
+                               factor_priorfacloadtype = "normal",
+                               factor_priorfacload = 1e6,
+                               factor_heteroskedastic = c(FALSE, FALSE),
+                               factor_priorhomoskedastic = matrix(c(1e-6,1e-6), ncol(data), 2))
+
+  mod <- bvar(data, lags = 2, prior_intercept = 1e6, prior_phi = phi,
+              prior_sigma = sigma, draws = 10, burnin = 10)
+  expect_true(all(mod$logvar[,-seq_len(ncol(mod$Y)),]==0))
+})
